==> react-advanced-number-0.2.0.tgz: package/lib/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import React from "react";
import { getPrefix, getInteger, getSeparator, getFraction, getSuffix, getComparisonDiffIndex, getDiffColor, getMutedDigits, extractSpanProps, } from "./utils";
import { DEFAULT_NEGATIVE_COLOR, DEFAULT_POSITIVE_COLOR, DEFAULT_SHADOW_COLOR, MUTED_DECIMALS_OPACITY, PRIVACY_SHADOW_BLUR_RADIUS, SMAL_DECIMALS_FONT_SIZE, } from "./constants";
/**
 * This component allows formatting and rendering a number using the {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat|Intl.NumberFormat API}. The formatting options of the API are provided as props of this component.
 *
 * In additiona, specific features are also provided such as:
 * - Optionaly have smaller decimals
 * - Highlighting a difference between the value and a previous value.
 * - A privacy mode, blurrying the value when enabled.
 * - Displaying muted decimals between a significant number and the total number of decimals
 *
 * If provided, the ref is forwarded to the root span element.
 */
export var AdvancedNumber = React.forwardRef(function (props, ref) {
    var value = props.value, locales = props.locales, options = props.options, _a = props.smallDecimals, smallDecimals = _a === void 0 ? false : _a, _b = props.privacyMode, privacyMode = _b === void 0 ? false : _b, _c = props.privacyShadowColor, privacyShadowColor = _c === void 0 ? DEFAULT_SHADOW_COLOR : _c, previousValue = props.previousValue, _d = props.positiveColor, positiveColor = _d === void 0 ? DEFAULT_POSITIVE_COLOR : _d, _e = props.negativeColor, negativeColor = _e === void 0 ? DEFAULT_NEGATIVE_COLOR : _e, significantDecimalDigits = props.significantDecimalDigits, _f = props.showMutedDecimals, showMutedDecimals = _f === void 0 ? false : _f, maxDecimalDigits = props.maxDecimalDigits;
    /* Ensure the prop 'significantDecimalDigits' is an integer between 0 and 20,
    as expected by Intl.NumberFormatOptions properties 'minimumFractionDigits'
    and 'maximumFractionDigits'.*/
    var fractionDigits = significantDecimalDigits &&
        significantDecimalDigits >= 0 &&
        significantDecimalDigits <= 20
        ? Math.floor(significantDecimalDigits)
        : undefined;
    /* Initialize the formatter.
    Note if the prop 'significantDecimalDigits' has been provided, it
    overrides the Intl.NumberFormatOptions properties 'minimumFractionDigits'
    and 'maximumFractionDigits'.*/
    var formatter = new Intl.NumberFormat(locales, __assign(__assign({}, options), { minimumFractionDigits: fractionDigits
            ? fractionDigits
            : options === null || options === void 0 ? void 0 : options.minimumFractionDigits, maximumFractionDigits: fractionDigits
            ? fractionDigits
            : options === null || options === void 0 ? void 0 : options.minimumFractionDigits }));
    // Format the value.
    var valueParts = formatter.formatToParts(value);
    // Extract the main parts from the parts returned by the formatter.
    var prefix = getPrefix(valueParts);
    var integer = getInteger(valueParts);
    var separator = getSeparator(valueParts);
    var fraction = getFraction(valueParts);
    var suffix = getSuffix(valueParts);
    // Prepare the variables used in the render functions.
    var neutralInteger = integer;
    var changedInteger = "";
    var neutralFraction = fraction;
    var changedFraction = "";
    // Compute the diff only if previousValue has been provided.
    if (previousValue) {
        var previousValueParts = formatter.formatToParts(previousValue);
        var previousInteger = getInteger(previousValueParts);
        var integerDiffIndex = getComparisonDiffIndex(integer, previousInteger);
        neutralInteger = integer.slice(0, integerDiffIndex);
        changedInteger = integer.slice(integerDiffIndex, integer.length + 1);
        if (integerDiffIndex < integer.length + 1) {
            neutralFraction = "";
            changedFraction = fraction;
        }
        else {
            var previousFraction = getFraction(previousValueParts);
            var fractionDiffIndex = getComparisonDiffIndex(fraction, previousFraction);
            neutralFraction = fraction.slice(0, fractionDiffIndex);
            changedFraction = fraction.slice(fractionDiffIndex, fraction.length + 1);
        }
    }
    var diffColor = getDiffColor(positiveColor, negativeColor, value, previousValue);
    // Render functions, basically wrapping the different parts into the span elements.
    var renderPrefix = function () { return (prefix ? _jsx("span", { children: prefix }, void 0) : null); };
    var renderInteger = function () { return (_jsxs("span", { children: [neutralInteger, changedInteger && (_jsx("span", __assign({ style: privacyMode ? {} : { color: diffColor } }, { children: changedInteger }), void 0))] }, void 0)); };
    var renderSeparator = function () { return (separator ? _jsx("span", { children: separator }, void 0) : null); };
    var renderFractions = function () { return (_jsxs("span", __assign({ style: smallDecimals ? { fontSize: SMAL_DECIMALS_FONT_SIZE } : {} }, { children: [neutralFraction, changedFraction ? (_jsxs("span", __assign({ style: privacyMode ? {} : { color: diffColor } }, { children: [changedFraction, renderMutedDecimals()] }), void 0)) : (_jsx(_Fragment, { children: renderMutedDecimals() }, void 0))] }), void 0)); };
    var renderMutedDecimals = function () {
        var _a = formatter.resolvedOptions(), minimumFractionDigits = _a.minimumFractionDigits, notation = _a.notation;
        if (!showMutedDecimals || notation !== "standard") {
            return null;
        }
        var maxFractionDigits = maxDecimalDigits && maxDecimalDigits >= 0 && maxDecimalDigits <= 20
            ? Math.floor(maxDecimalDigits)
            : undefined;
        if (!maxFractionDigits) {
            return null;
        }
        var mutedDecimals = getMutedDigits(minimumFractionDigits, maxFractionDigits);
        return mutedDecimals ? (_jsx("span", __assign({ style: { opacity: MUTED_DECIMALS_OPACITY } }, { children: mutedDecimals }), void 0)) : null;
    };
    var renderSuffix = function () { return (suffix ? _jsx("span", { children: suffix }, void 0) : null); };
    var getRootStyle = function (style) {
        return privacyMode
            ? __assign(__assign({}, style), { color: "transparent", textShadow: "0 0 " + PRIVACY_SHADOW_BLUR_RADIUS + " " + privacyShadowColor }) : style;
    };
    // Get clean props to forward to the root span element.
    var rootProps = extractSpanProps(props);
    return (_jsxs("span", __assign({ ref: ref }, rootProps, { style: getRootStyle(rootProps.style) }, { children: [renderPrefix(), renderInteger(), renderSeparator(), renderFractions(), renderSuffix()] }), void 0));
});

==> react-advanced-number-1.0.0.tgz: package/lib/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import React from "react";
import { getPrefix, getInteger, getSeparator, getFraction, getSuffix, getComparisonDiffIndex, getDiffColor, getMutedDigits, extractSpanProps, } from "./utils";
import { DEFAULT_NEGATIVE_COLOR, DEFAULT_POSITIVE_COLOR, DEFAULT_SHADOW_COLOR, MUTED_DECIMALS_OPACITY, PRIVACY_SHADOW_BLUR_RADIUS, SMAL_DECIMALS_FONT_SIZE, } from "./constants";
/**
 * This component allows formatting and rendering a number using the {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat|Intl.NumberFormat API}. The formatting options of the API are provided as props of this component.
 *
 * In addition, specific features are also provided such as:
 * - Optionaly have smaller decimals
 * - Highlighting a difference between the value and a previous value.
 * - A privacy mode, blurrying the value when enabled.
 * - Displaying muted decimals between a significant number and the total number of decimals
 *
 * If provided, the ref is forwarded to the root span element.
 */
export var AdvancedNumber = React.forwardRef(function (props, ref) {
    var value = props.value, locales = props.locales, options = props.options, _a = props.smallDecimals, smallDecimals = _a === void 0 ? false : _a, _b = props.privacyMode, privacyMode = _b === void 0 ? false : _b, _c = props.privacyShadowColor, privacyShadowColor = _c === void 0 ? DEFAULT_SHADOW_COLOR : _c, previousValue = props.previousValue, _d = props.positiveColor, positiveColor = _d === void 0 ? DEFAULT_POSITIVE_COLOR : _d, _e = props.negativeColor, negativeColor = _e === void 0 ? DEFAULT_NEGATIVE_COLOR : _e, significantDecimalDigits = props.significantDecimalDigits, _f = props.showMutedDecimals, showMutedDecimals = _f === void 0 ? false : _f, maxDecimalDigits = props.maxDecimalDigits;
    /* Ensure the prop 'significantDecimalDigits' is an integer between 0 and 20,
    as expected by Intl.NumberFormatOptions properties 'minimumFractionDigits'
    and 'maximumFractionDigits'.*/
    var fractionDigits = significantDecimalDigits &&
        significantDecimalDigits >= 0 &&
        significantDecimalDigits <= 20
        ? Math.floor(significantDecimalDigits)
        : undefined;
    /* Initialize the formatter.
    Note if the prop 'significantDecimalDigits' has been provided, it
    overrides the Intl.NumberFormatOptions properties 'minimumFractionDigits'
    and 'maximumFractionDigits'.*/
    var formatter = new Intl.NumberFormat(locales, __assign(__assign({}, options), { minimumFractionDigits: fractionDigits
            ? fractionDigits
            : options === null || options === void 0 ? void 0 : options.minimumFractionDigits, maximumFractionDigits: fractionDigits
            ? fractionDigits
            : options === null || options === void 0 ? void 0 : options.minimumFractionDigits }));
    // Format the value.
    var valueParts = formatter.formatToParts(value);
    // Extract the main parts from the parts returned by the formatter.
    var prefix = getPrefix(valueParts);
    var integer = getInteger(valueParts);
    var separator = getSeparator(valueParts);
    var fraction = getFraction(valueParts);
    var suffix = getSuffix(valueParts);
    // Prepare the variables used in the render functions.
    var neutralInteger = integer;
    var changedInteger = "";
    var neutralFraction = fraction;
    var changedFraction = "";
    // Compute the diff only if previousValue has been provided.
    if (previousValue) {
        var previousValueParts = formatter.formatToParts(previousValue);
        var previousInteger = getInteger(previousValueParts);
        var integerDiffIndex = getComparisonDiffIndex(integer, previousInteger);
        neutralInteger = integer.slice(0, integerDiffIndex);
        changedInteger = integer.slice(integerDiffIndex);
        if (integerDiffIndex < integer.length) {
            neutralFraction = "";
            changedFraction = fraction;
        }
        else {
            var previousFraction = getFraction(previousValueParts);
            var fractionDiffIndex = getComparisonDiffIndex(fraction, previousFraction);
            neutralFraction = fraction.slice(0, fractionDiffIndex);
            changedFraction = fraction.slice(fractionDiffIndex);
        }
    }
    var diffColor = getDiffColor(positiveColor, negativeColor, value, previousValue);
    // Render functions, basically wrapping the different parts into the span elements.
    var renderPrefix = function () { return (prefix ? _jsx("span", { children: prefix }, void 0) : null); };
    var renderInteger = function () { return (_jsxs("span", { children: [neutralInteger, changedInteger && (_jsx("span", __assign({ style: privacyMode ? {} : { color: diffColor } }, { children: changedInteger }), void 0))] }, void 0)); };
    var renderSeparator = function () { return (separator ? _jsx("span", { children: separator }, void 0) : null); };
    var renderFractions = function () {
        return neutralFraction || changedFraction ? (_jsxs("span", __assign({ style: smallDecimals ? { fontSize: SMAL_DECIMALS_FONT_SIZE } : {} }, { children: [neutralFraction, changedFraction ? (_jsxs("span", __assign({ style: privacyMode ? {} : { color: diffColor } }, { children: [changedFraction, renderMutedDecimals()] }), void 0)) : (_jsx(_Fragment, { children: renderMutedDecimals() }, void 0))] }), void 0)) : null;
    };
    var renderMutedDecimals = function () {
        var _a = formatter.resolvedOptions(), minimumFractionDigits = _a.minimumFractionDigits, notation = _a.notation;
        if (!showMutedDecimals || notation !== "standard") {
            return null;
        }
        var maxFractionDigits = maxDecimalDigits && maxDecimalDigits >= 0 && maxDecimalDigits <= 20
            ? Math.floor(maxDecimalDigits)
            : undefined;
        if (!maxFractionDigits) {
            return null;
        }
        var mutedDecimals = getMutedDigits(minimumFractionDigits, maxFractionDigits);
        return mutedDecimals ? (_jsx("span", __assign({ style: { opacity: MUTED_DECIMALS_OPACITY } }, { children: mutedDecimals }), void 0)) : null;
    };
    var renderSuffix = function () { return (suffix ? _jsx("span", { children: suffix }, void 0) : null); };
    var getRootStyle = function (style) {
        return privacyMode
            ? __assign(__assign({}, style), { color: "transparent", textShadow: "0 0 " + PRIVACY_SHADOW_BLUR_RADIUS + " " + privacyShadowColor }) : style;
    };
    // Get clean props to forward to the root span element.
    var rootProps = extractSpanProps(props);
    return (_jsxs("span", __assign({ ref: ref }, rootProps, { style: getRootStyle(rootProps.style) }, { children: [renderPrefix(), renderInteger(), renderSeparator(), renderFractions(), renderSuffix()] }), void 0));
});
